// 放到所有代码的最顶部
// 定义差集的方法（兼容WebView 没有该方法）
if (typeof Set.prototype.difference !== 'function') {
  Set.prototype.difference = function (setB) {
    // 创建一个新的集合，用于存储差集结果
    let differenceSet = new Set(this);

    // 遍历传入的集合 setB
    for (let elem of setB) {
      // 如果当前集合中包含 setB 的元素，则从 differenceSet 中删除
      differenceSet.delete(elem);
    }

    // 返回差集结果
    return differenceSet;
  };
}

(function() {
    function domReady(callback) {
      if (document.readyState === "loading") {
        document.addEventListener("DOMContentLoaded", function () {
          callback();
        });
      } else {
        callback();
      }
    }

    /**
     * 获取页面中所有节点的 id 和 类 名称。并返回给 callback 使用
     * 要在 DOMContentLoaded 监听事件里面执行
     *
     * @param {Function} callback 回调函数
     * @param {number} [300] wait - 单位 ms，默认 300ms
     * @returns
     */
    function getAllUniqueIdsAndClasses(callback, wait = 300) {
      // 存储唯一的id和class
      const uniqueIds = new Set();
      const uniqueClasses = new Set();

      /**
       * 创建一个防抖函数
       * @param {Function} func - 需要防抖的函数
       * @param {number} wait - 延迟执行的时间，单位为毫秒
       * @returns 防抖后的函数
       */
      function debounce(func, wait) {
        let timeout;

        // 返回一个新的函数，用来处理延迟执行
        return function (...args) {
          // 清除之前的延迟调用
          clearTimeout(timeout);

          // 设置新的延迟调用
          timeout = setTimeout(() => {
            func.apply(this, args);
          }, wait);
        };
      }

      function updateElementIdsAndClasses(element) {
        if (element) {
          if (element.id) {
            uniqueIds.add(element.id);
          }

          if (element.classList && element.classList.length > 0) {
            element.classList.forEach((className) => {
              uniqueClasses.add(className);
            });
          }
        }
      }

      function updateAllIdsAndClasses(root = document) {
        if (root) {
          updateElementIdsAndClasses(root);

          if (typeof root.querySelectorAll === 'function') {
            root.querySelectorAll('*').forEach((element) => {
              updateElementIdsAndClasses(element);
            });
          }
        }
      }

      /**
       * 需要执行的函数，主要透传数据给 callback
       */
      function handler() {
        if (uniqueIds.size === 0 && uniqueClasses.size === 0) {
          return;
        }

        callback({
          ids: uniqueIds,
          classes: uniqueClasses
        });

        uniqueIds.clear();
        uniqueClasses.clear();
        console.log('handler: clear' + uniqueIds.size + ',' + uniqueClasses.size);
      }

      // 避免 DOM 快速更新时，执行得太频繁。
      // 当 DOM 停止更新后的 wait 时间再执行 handler
      const debounceCallback = debounce(() => {
        handler();
      }, wait);

      // 回调函数，第三方可以使用它来获取更新后的id和class数组
      function onDOMUpdate() {
        // 创建MutationObserver监听DOM变化
        const observer = new MutationObserver((mutationsList) => {
          const nodeHandler = (node) => {
            updateAllIdsAndClasses(node);
            debounceCallback();
          };

          // 定义一个回调函数，当DOM变化时会调用这个函数
          for (const mutation of mutationsList) {
            if (mutation.type === 'childList') {
              mutation.addedNodes.forEach((node) => {
                nodeHandler(node);
              });
            } else if (mutation.type === 'attributes') {
              const node = mutation.target;
              nodeHandler(node);
            }
          }
        });

        // 配置观察选项
        const config = {
          attributes: true, // 监听属性变化
          childList: true, // 监听子节点的变化（添加/删除）
          subtree: true, // 监听目标节点的所有后代节点
          attributeFilter: ['class', 'id'] // 只监听 class 和 id 属性的变化
        };

        // 传入目标节点（文档的根节点）和观察选项，开始观察
        observer.observe(document, config);

        // 立即执行收集一次全部的 dom 的 id 和 className
        updateAllIdsAndClasses();

        // 立即把上面收集的数据给一次 callback
        handler();

        // 返回一个函数，第三方可以调用它来停止监听DOM变化
        return () => observer.disconnect();
      }

      return onDOMUpdate();
    }

    if (window.___adb2 == null) {
        window.___adb2 = new Date().getTime();
            //hide_selectors
            //style_selectors
            //remove_selectors
            //remove_attrs
            //remove_classes
            //exceptions
            //injected_script
            //generichide
            //上面的根据url从广告引擎中获取 下面的ids和classes是从dom中获取的
            // uniqueIds
            // uniqueClasses
        var cosmeticResources = null;//{};
        var hideElementsStrong = {
            strongSelectors: null,
            getStandardTags: function() {
                return "<a><abbr><acronym><address><applet><area><article><aside><audio><b><base><basefont><bdi>"
                       + "<bdo><big><blockquote><body><br><button><canvas><caption><center><cite><code><col><colgroup>"
                       + "<command><datalist><dd><del><details><dfn><dialog><dir><div><dl><dt><em><embed><fieldset>"
                       + "<figcaption><figure><font><footer><form><frame><frameset><head><header><hgroup><h1><h2>"
                       + "<h3><h4><h5><h6><hr><i><iframe><img><input><ins><kbd><keygen><label><legend><li><link>"
                       + "<main><map><mark><menu><meta><meter><nav><noframes><noscript><object><ol><optgroup>"
                       + "<option><output><p><param><pre><html><picture><progress><q><rp><rt><ruby><s><samp>"
                       + "<script><section><select><small><source><span><strike><strong><style><sub><summary>"
                       + "<sup><table><tbody><td><textarea><template><tfoot><th><thead><time><title><tr>"
                       + "<track><tt><u><ul><var><video><wbr><svg><path><rect><ellipse><line><circle>"
                       + "<polygon><polyline><text><element><filter><feGaussianBlur><feOffset><linearGradient>"
                       + "<radialGradient><stop><defs><x-video>";
            },
            getElementCSS: function(curEle, attr) {
                if (curEle.currentstyle != null) {
                    return curEle.currentstyle[attr];
                }
                var s = document.defaultView.getComputedStyle(curEle, null);
                if (s != null) {
                    return s[attr];
                }
                return null;
            },
            isNeedHideBlockElement: function(s) {
                if (!s) {
                    return false;
                }

                if (s.id && (typeof s.id === 'string') && (s.id.indexOf('x_ele_') >= 0 || s.id.indexOf('xbt_') >= 0)) {
                    return false;
                }

                if (s.getAttribute != null) {
                    var attr = s.getAttribute('x-ele');
                    if (attr != null) {
                        return false;
                    }
                }

                if (hideElementsStrong.strongSelectors == null) {
                    hideElementsStrong.strongSelectors = XWebViewApi.getElementHidingSelectors(XWebViewApi.ADBLOCK_OPTION_HIDING_SELECTORS_STRONG); //[[{}, {}], [{}, {}]]
                    console.log('parsed hiding strong selectors: ' + hideElementsStrong.strongSelectors.length);
                }

                var tags = hideElementsStrong.getStandardTags();
                for (let item of hideElementsStrong.strongSelectors) {
                    var selectors = XWebViewApi.parse(item, []);
                    for (let selector of selectors) {
                        var ret = false;
                        var retLog = '';

                        if (selector.tag != null && selector.tag.length > 0) {
                            if (s.tagName == null || s.tagName.length <= 0) {
                                ret = false;
                            } else if (selector.tag === '!standard') {
                                ret = tags.indexOf(s.tagName.toLowerCase()) < 0;
                            } else {
                                selector.tagRegex = selector.tagRegex || new RegExp(selector.tag);
                                ret = selector.tagRegex.test(s.tagName.toLowerCase());
                            }

                            if (ret) {
                                retLog = 'hide block ele by tag:' + s.tagName + '@' + selector.tag;
                            }
                        }

                        if (selector.id != null && selector.id.length > 0) {
                            if (s.id == null || s.id.length <= 0) {
                                ret = false;
                            } else {
                                selector.idRegex = selector.idRegex || new RegExp(selector.id);
                                ret = selector.idRegex.test(s.id);
                            }

                            if (ret) {
                                retLog = 'hide block ele by id:' + s.id + '@' + selector.id;
                            }
                        }

                        if (selector.class != null && selector.class.length > 0) {
                            if (s.className == null || s.className.length <= 0) {
                                ret = false;
                            } else {
                                selector.classRegex = selector.classRegex || new RegExp(selector.class);
                                ret = selector.classRegex.test(s.className);
                            }

                            if (ret) {
                                retLog = 'hide block ele by class:' + s.className + '@' + selector.class;
                            }
                        }

                        if (selector.style != null && selector.style.length > 0) {
                            if (s.style == null || s.style.length <= 0) {
                                ret = false;
                            } else {
                                var styles = '';
                                for (var i = 0; i < s.style.length; ++i) {
                                    var prop = s.style[i];
                                    if (s.style[prop] != null && s.style[prop].length > 0) {
                                        styles = styles + prop + ':' + s.style[prop] + ';';
                                    }
                                }

                                if (styles.length <= 0) {
                                    ret = false;
                                } else {
                                    selector.styleRegex = selector.styleRegex || new RegExp(selector.style);
                                    ret = selector.styleRegex.test(styles);
                                }
                            }

                            if (ret) {
                                retLog = 'hide block ele by styles:' + styles + '@' + selector.style;
                            }
                        }

                        if (selector.css != null && selector.css.length > 0) {
                            var css = hideElementsStrong.getElementCSS(s, 'background');
                            if (css == null || css.length <= 0) {
                                ret = false;
                            } else {
                                selector.cssRegex = selector.cssRegex || new RegExp(selector.css);
                                ret = selector.cssRegex.test(css);
                            }

                            if (ret) {
                                retLog = 'hide block ele by css:' + css + '@' + selector.css;
                            }
                        }

                        if (selector.innerHTML != null && selector.innerHTML.length > 0) {
                            var innerHTML = s.innerHTML;
                            if (innerHTML == null || innerHTML.length <= 0) {
                                ret = false;
                            } else {
                                selector.innerHTMLRegex = selector.innerHTMLRegex || new RegExp(selector.innerHTML);
                                ret = selector.innerHTMLRegex.test(innerHTML);
                            }

                            if (ret) {
                                retLog = 'hide block ele by innerHTML:' + innerHTML + '@' + selector.innerHTML;
                            }
                        }

                        if (ret) {
                            if (XWebViewApi.debugMode()) {
                                console.log(retLog);
                            }
                            return true;
                        }
                    }
                }

                return false;
            },
            getElementInfo: function(e) {
                var styles = '';
                for (var i = 0; e.style != null && i < e.style.length; ++i) {
                    var prop = e.style[i];
                    if (e.style[prop] != null && e.style[prop].length > 0) {
                        styles = styles + prop + ':' + e.style[prop] + ';';
                    }
                }
                return "node:" + e.tagName + ", id:" + e.id + ", class:" + e.className + ", style:" + styles;
            },
            hideElement: function(e, debug) {
                if (debug) {
                    console.log("hideElement " + hideElementsStrong.getElementInfo(e));
                }
                if (e.parentNode) {
                    e.parentNode.removeChild(e);
                } else {
                    e.style.display = 'none !important';
                    e.style.height = "0 !important"
                    e.style.overflow = 'hidden !important'
                }
            },
            hideBlockElement: function(e, disableCheck) {
                var debug = false;
                if (!disableCheck && hideElementsStrong.isNeedHideBlockElement(e)) {
                    hideElementsStrong.hideElement(e, debug);
                } else {
                    if (e && e.childElementCount > 0) {
                        var removed = [];
                        for (let node of e.children) {
                            if (hideElementsStrong.isNeedHideBlockElement(node)) {
                                removed.push(node);
                            } else if (node.childElementCount > 0) {
                                hideElementsStrong.hideBlockElement(node, true);
                            }
                        }

                        if (removed.length > 0) {
                            for (let node of removed) {
                                hideElementsStrong.hideElement(node, debug);
                            }

                            if (e.childElementCount <= 0) {
                                hideElementsStrong.hideElement(e, debug);
                            }
                        }
                    }
                }
            },
            checkDyAds: function() {
                /*var d = document.querySelectorAll('div[style*="background:#000;opacity:0.01;"]');
                if (d != null && d.length > 1) {
                    hideElementsStrong.strongSelectors.push('[{"tag":"!standard"}]');

                    //height: 133.44px; margin-bottom: 0px; margin-left: 0px;
                    d = document.querySelectorAll('div[style*="height:"]');
                    if (d != null && d.length > 1) {
                        for (i = 0; i < d.length; ++i) {
                            if (d[i].id == d[i].className) {
                                hideElementsStrong.hideElement(d[i].parentNode);
                                break;
                            }
                        }
                    }
                    return true;
                }*/
                return false;
            }
        };

        function hideElementsByStyleSheets(hiddenFlag) {
            if (document[hiddenFlag] === true) {
                console.log('already hidden, exiting');
                return;
            }
            document[hiddenFlag] = true; // set flag not to do it again
            console.log("Not yet hidden! starting injecting css rules")

            var selectors = XWebViewApi.getElementHidingStyleSheets();
            console.log('parsed hiding style sheets: ' + selectors.length);

            var head = document.getElementsByTagName("head")[0];
            for (var i = 0; i < selectors.length; i++) {
                var txt = selectors[i].replace(/{display: none !important;}/g, '{display: none !important; height: 0 !important; overflow: hidden !important;}')
                var style = document.createElement("style");
                style.id = 'x_browser_hide_style_' + i;
                head.appendChild(style);
                style.textContent = txt;
            }

            console.log('finished injecting css rules');
        };

        function hideElementsByStrongRule(hiddenFlag) {
            if (document[hiddenFlag] === true) {
                console.log('already hidden, exiting');
                return;
            }
            document[hiddenFlag] = true; // set flag not to do it again
            console.log("Not yet hidden! starting monit")

            var hasDyAds = false;
            new MutationObserver(function(mutationsList) {
                //console.log("body changed:" + mutationsList.length);
                for (let mutation of mutationsList) {
                    if (mutation.type === 'childList') {
                        //console.log('A child node has been added or removed.');
                        if (!hasDyAds && hideElementsStrong.checkDyAds()) {
                            hasDyAds = true;
                            hideElementsStrong.hideBlockElement(document);
                        } else if (mutation.addedNodes != null) {
                            for (let node of mutation.addedNodes) {
                                if (hideElementsStrong.isNeedHideBlockElement(node)) {
                                    //console.log('A child node has been added and remove it who not in normal tag list:' + node.tagName);
                                    hideElementsStrong.hideElement(node);
                                } else {
                                    hideElementsStrong.hideBlockElement(node);
                                }
                                XWebViewApi.invokeCommand('elementchange', node);
                            }
                        }
                    } else if (mutation.type === 'attributes') {
                        console.log('The ' + mutation.attributeName + ' attribute was modified.');
                    }
                }
            }).observe(document, {subtree: true, childList: true});

            hideElementsStrong.hideBlockElement(document);
            console.log('finished monit');
        };

        function loadCosmeticResources(hiddenFlag) {
            if (document[hiddenFlag] === true) {
                console.log('already hidden, exiting');
                return;
            }
            document[hiddenFlag] = true; // set flag not to do it again
            console.log('loadCosmeticResources');
            if (cosmeticResources === undefined || !cosmeticResources) {
                cosmeticResources = XWebViewApi.getCosmeticResources();
            }
            if (XWebViewApi.debugMode()) {
                window.cosmeticResources = cosmeticResources;
            }
            if (!cosmeticResources || Object.keys(cosmeticResources).length == 0) {
                console.log('no cosmeticResources');
                return;
            }
            // 添加当前域名的规则
            var head = document.getElementsByTagName("head")[0];
            
            /** 
             * hide_selectors 是指广告引擎里面，解析规则后，提取出属性或元素开头的规则，例如
             * - [data-testid^=\"taboola-\"]
             * - body[ontouchstart] > div[id^=\"content_\"][style=\"display: block;\"
             * - div[id^=\"dfp-ad-\"]
             * - a[href^=\"https://ndt5.net/\"] 
             * 
             * 等等。即没办法通过元素的 id 或 class，引擎无法单纯提取的规则。
             * 这类规则大概 1000 个左右。同一放到 x_browser_hide_style_special_selectors style 里面
             */
            var selectors = cosmeticResources.hide_selectors;
            if (selectors && selectors.length > 0) {
                let txt = '';
                let len = selectors.length;
                let start = 0
                while(start < len) {
                    let list = selectors.slice(start, start + Math.min(len, start + 1024));
                    start += list.length;
                    txt += list.join(',');
                    txt += " {display: none !important; height: 0 !important; overflow: hidden !important;}" + String.fromCharCode(10);
                }
                let style = document.createElement("style");
                style.id = 'x_browser_hide_style_special_selectors';
                head.appendChild(style);
                style.textContent = txt;
            }
            
            /**
             * style_selectors 
             * https://github.com/brave/adblock-rust/blob/master/src/cosmetic_filter_cache.rs
             * 目前新版本已去除 style_selectors。代替的是：procedural_actions 
             * 重点看这次的 commit：https://github.com/brave/adblock-rust/commit/285d05658222bce8452fa6cca1780d27dedcc027
             * adblock 规则项目，搜索了下 :style 语法，大概有 7000 个这类规则。
             * 引擎返回的数据格式是：
             * {
             *   "选择器": ["规则 1", "规则 2", ...],
             * }
             * 
             * 例如 (你也可以在 chrome 上使用 uBlock Origin 的「自定义静态规则」来模拟和查看效果)：
             * 1）google.*##[data-lyricid]:style(user-select: text !important;) 
             * => 
             * style_selectors: {
             *  "[data-lyricid]": ["user-select: text !important;"]
             * }
             * =>
             * 在页面上生成的 style 的代码是：[data-lyricid] {user-select: text !important;}
             * 
             * 2）apkmirror.com##.advertisement-text:style(height: 1px!important; top: 0px !important) 
             * =>
             * style_selectors: {
             *  ".advertisement-text": ["height: 1px!important;", "top: 0px !important"]
             * }
             * =>
             * 在页面上生成的 style 的代码是：.advertisement-text {height: 1px!important; top: 0px !important;}
             */
            var styles = cosmeticResources.style_selectors;
            if (styles) {
                let txt = '';
                for(let selector in styles) {
                    // FIX BEGIN: 当初解析问题 ======================================================
                    // if (styles.hasOwnProperty(key)) {
                    //     txt += styles[key].join(',') + key + String.fromCharCode(10);
                    // }
                    // 对数组进行处理，如果每一个值的末尾没有添加英文「;」分号，那就进行添加，避免规则代码错误
                    // 例如：".advertisement-text": ["height: 1px!important", "top: 0px !important"] =》
                    // => ".advertisement-text" {height: 1px!important; top: 0px !important;}
                    let values = styles[selector];
                    
                    // 万一引擎给到的值不是数组，那就转成数组
                    if(!Array.isArray(values)) {
                        values = [values];
                    }
                    
                    for (let i = 0; i < values.length; i++) {
                        if (values[i].slice(-1) !== ';') {
                            values[i] += ';';
                        }
                    }
                    
                    txt += `${selector} {${values.join(' ')}}` + String.fromCharCode(10);
                    // FIX END ===============================================================
                }
                if (txt.length > 0) {
                    let style = document.createElement("style");
                    style.id = 'x_browser_hide_style_special_styles';
                    head.appendChild(style);
                    style.textContent = txt;
                }
            }

            if(cosmeticResources.generichide !== undefined && !cosmeticResources.generichide) {
                // 添加通用规则
                let stopListening = getAllUniqueIdsAndClasses(hideCommonElements, 100);
                // 10秒后自动停止DOM监听
//                 setTimeout(() => {
//                     stopListening();
//                 }, 10 * 1000);
            }
            if(!cosmeticResources.injected_script) {
                // 注入js
                eval(cosmeticResources.injected_script);
            }
        };

        function hideElements() {
            var meta = document.querySelector('meta[name=xl-app-page]');
            if (meta == null) {
                //hideElementsByStyleSheets('x-code-css:' + window.___adb2);
                hideElementsByStrongRule('x-code-strong:' + window.___adb2);
                loadCosmeticResources('x-code-resources:' + window.___adb2);
            } else {
                console.log('xl app page');
            }
        };

        /**
         * 通过获取页面的 class 和 id（包括页面后续的动态更新 DOM），来给到引擎。引擎会根据这些 id 和 class，来返回对应的 css 规则。
         * 然后把这些 css 规则放到 style id = x_browser_hide_style_common_xxx 里面
         * @param {object} params - 里面有 ids 和 classes 的集合
         * @param {Set} params.ids - 页面 id 的集合
         * @param {Set} params.classes - 页面 class 的集合
         * @example  https://acgmhd.com/h/622798.html 生成的大概例子
         * <style id="x_browser_hide_style_common_1746676741956">
         * .title > .gg,.footer + .block > .jsv-bottom > .jsv-content > .jsv-box,#search > a[href="/top1.html"],
         * .content > #dhxhtml,.content > .small-icon-container > a.small-icon-div[target="_blank"],
         * .content > a > .topline,.footer > .tongji323,.search + #midBox,
         * .ad-col {display: none !important; height: 0 !important; overflow: hidden !important;}
         * </style>
         */
        function hideCommonElements(params) {
            if(!cosmeticResources || Object.keys(cosmeticResources).length == 0) {
                return
            }
            console.log("hideCommonElements:" + params.ids.size + "," + params.classes.size);
            if(!cosmeticResources.uniqueIds) {
                cosmeticResources.uniqueIds = new Set();
            }
            if(!cosmeticResources.uniqueClasses) {
                cosmeticResources.uniqueClasses = new Set();
            }
            let uniqueIds = params.ids.difference(cosmeticResources.uniqueIds);
            let uniqueClasses = params.classes.difference(cosmeticResources.uniqueClasses);
            if (uniqueIds.size == 0 && uniqueClasses.size == 0) {
                console.log("hideCommonElements no difference");
                return
            }
            console.log("hideCommonElements add:" + uniqueIds.size + "," + uniqueClasses.size);
            for (let uniqueId of uniqueIds) {
                cosmeticResources.uniqueIds.add(uniqueId)
            }
            for (let uniqueClass of uniqueClasses) {
                cosmeticResources.uniqueClasses.add(uniqueClass)
            }
            let ids = Array.from(uniqueIds).join(',');
            let classes = Array.from(uniqueClasses).join(',');
            let exceptions = cosmeticResources.exceptions ? cosmeticResources.exceptions.join(',') : "";
            let selectors = XWebViewApi.getElementHidingSelectorsWithIdsClasses(ids, classes, exceptions).split(',');
            let len = selectors.length;
            if(len == 0) {
                console.log("hideCommonElements no selectors");
                return
            }
            if(len == 1 && selectors[0] == '') {
                console.log("hideCommonElements no selectors");
                return
            }
            
            // 进行收集。统一放到 cosmeticResources 里面。方便 debug 调试
            if(!Array.isArray(cosmeticResources.elementHidingSelectors)) {
                cosmeticResources.elementHidingSelectors = [];
            }
            cosmeticResources.elementHidingSelectors.push(...selectors);
            
            let txt = '';
            let start = 0
            while(start < len) {
                let list = selectors.slice(start, start + Math.min(len, start + 1024));
                start += list.length;
                txt += list.join(',');
                txt += " {display: none !important; height: 0 !important; overflow: hidden !important;}" + String.fromCharCode(10);
            }
            let style = document.createElement("style");
            style.id = 'x_browser_hide_style_common_' + new Date().getTime();
            document.head.appendChild(style);
            style.textContent = txt;
        };

        function getElementHidingSelectors() {
            if(!cosmeticResources || Object.keys(cosmeticResources).length == 0) {
                console.log("getElementHidingSelectors before loadCosmeticResources");
                cosmeticResources = XWebViewApi.getCosmeticResources();
                if (XWebViewApi.debugMode()) {
                    window.cosmeticResources = cosmeticResources;
                }
            }
            let selectors = []
            if(cosmeticResources.hide_selectors) {
                selectors.push(...cosmeticResources.hide_selectors);
            }
            if(cosmeticResources.style_selectors) {
                // FIX BEGIN style_selectors 的数据格式解析 =================================================
                // for(let key in cosmeticResources.style_selectors) {
                //     if (styles.hasOwnProperty(key)) {
                //         selectors.push(...cosmeticResources.style_selectors[key]);
                //     }
                // }
                // cosmeticResources.style_selectors 的 key 就是选择器
                for(let selector in cosmeticResources.style_selectors) {
                    selectors.push(selector);
                }
                // FIX END ====================================================
            }
            
            // ===============  FIX BEGIN ================================
            // ==== 这里的 uniqueIds 和 uniqueClasses 是页面动态的 DOM，大概率不是被命中要隐藏的元素，所以需要从 elementHidingSelectors 里面拿 ====
            // if(cosmeticResources.uniqueIds) {
            //     selectors.push(...cosmeticResources.uniqueIds);
            // }
            // if(cosmeticResources.uniqueClasses) {
            //     selectors.push(...cosmeticResources.uniqueClasses);
            // }
            // 
            if(cosmeticResources.elementHidingSelectors) {
                selectors.push(...cosmeticResources.elementHidingSelectors);
            }
            // =============== FIX END ====================================
            
            return selectors;
        }

        domReady(function() {
            hideElements();
        })
        window.addEventListener('load', hideElements, true);

        // 上报使用
        XWebViewApi.registerCommand('getElementHidingSelectors', getElementHidingSelectors);
    }
})();